@@ -275,6 +275,7 @@ class CMaker:
             cmake_source_dir,
             "-G",
             generator.name,
+            "--no-warn-unused-cli",
             f"-DCMAKE_INSTALL_PREFIX:PATH={cmake_install_prefix}",
             f"-DPYTHON_VERSION_STRING:STRING={python_version_string}",
             "-DSKBUILD:INTERNAL=TRUE",
@@ -296,7 +297,7 @@ class CMaker:
             )
             if python_include_dir:
                 cmd.append(f"{prefix}_INCLUDE_DIR:PATH={python_include_dir}")
-            if python_library:
+            if python_library and sysconfig.get_platform().startswith("win"):
                 cmd.append(f"{prefix}_LIBRARY:PATH={python_library}")
             if sys.implementation.name == "pypy":
                 cmd.append(f"{prefix}_FIND_IMPLEMENTATIONS:STRING=PyPy")
@@ -340,7 +341,7 @@ class CMaker:
         rtn = subprocess.run(cmd, cwd=CMAKE_BUILD_DIR(), env=generator.env, check=False).returncode
         if rtn != 0:
             msg = textwrap.dedent(
-                """\
+                f"""\
                 An error occurred while configuring with CMake.
                   Command:
                     {self._formatArgsForDisplay(cmd)}
@@ -599,9 +600,7 @@ class CMaker:
                     python_library = candidate
                     break
 
-        # TODO(opadron): what happens if we don't find a libpython?
-
-        return python_library
+        return python_library if python_library and os.path.exists(python_library) else None
 
     @staticmethod
     def check_for_bad_installs() -> None:
@@ -638,17 +637,16 @@ class CMaker:
                         bad_installs.append(os.path.join(destination, os.path.basename(match.group(2))))
 
         if bad_installs:
-            raise SKBuildError(
-                "\n".join(
-                    (
-                        "  CMake-installed files must be within the project root.",
-                        "    Project Root:",
-                        "      " + install_dir,
-                        "    Violating Files:",
-                        "\n".join(("      " + _install) for _install in bad_installs),
-                    )
+            msg = "\n".join(
+                (
+                    "  CMake-installed files must be within the project root.",
+                    "    Project Root:",
+                    f"      {install_dir}",
+                    "    Violating Files:",
+                    "\n".join(f"      {_install}" for _install in bad_installs),
                 )
             )
+            raise SKBuildError(msg)
 
     def make(
         self,
